Exception: Jekyll::L10n::Errors::BaseError
- Inherits:
-
StandardError
- Object
- StandardError
- Jekyll::L10n::Errors::BaseError
- Defined in:
- lib/jekyll-l10n/errors.rb
Overview
Base error class for all jekyll-l10n exceptions
All custom exceptions in the plugin inherit from this class, allowing for both specific exception handling and generic catching of all jekyll-l10n errors.
Direct Known Subclasses
ConfigurationError, ExtractionError, LibreTranslateError, PoFileError, TranslationError